@@ -59,7 +59,7 @@ class TextPreprocessor:
 
         self.CHARS_PUNCT_ASIS = '+.,:;!?-'
         self.CHARS_PUNCT = '()/"\'«»„“' + self.CHARS_PUNCT_ASIS
-        self.CHARS_ALLOWED = '$€%&~№0-9A-Za-zЁА-Яёа-я’²³°' + self.CHARS_PUNCT
+        self.CHARS_ALLOWED = '$€%&~№0-9A-Za-zЁА-Яёа-я`’²³°' + self.CHARS_PUNCT
         self.CHARS_CAPITAL = ''.join(chr(i) for i in range(2**16)
                                                 if chr(i).istitle()
                                                and chr(i).isalpha())
@@ -940,9 +940,12 @@ class TextPreprocessor:
             idx = tokens.index("'")
         except ValueError:
             try:
-                idx = tokens.index("’")
+                idx = tokens.index('’')
             except ValueError:
-                idx = -1
+                try:
+                    idx = tokens.index('`')
+                except ValueError:
+                    idx = -1
         if idx > 0 and tokens[idx - 1].isalpha() \
                    and tokens[idx + 1].isalpha() \
                    and tokens[idx + 1].istitle():
